@@ -1,11 +1,22 @@
 import os
 import logging
+import sys
 import time
 import json
 import redis
 import attr
 import io
-import multiprocessing as mp
+try:
+    import torch.multiprocessing as mp
+    try:
+        mp.set_start_method('spawn')
+    except RuntimeError:
+        pass
+except ImportError:
+    import multiprocessing as mp
+import importlib
+import importlib.util
+import inspect
 
 from typing import Dict
 from abc import ABC, abstractmethod
@@ -16,13 +27,14 @@ from redis import Redis
 from rq import Queue, get_current_job
 from rq.registry import StartedJobRegistry, FinishedJobRegistry, FailedJobRegistry
 from rq.job import Job
+from colorama import Fore
+
+from label_studio_tools.core.utils.params import get_bool_env
+from label_studio_tools.core.label_config import parse_config
+from label_studio_tools.core.utils.io import get_local_path
 
 logger = logging.getLogger(__name__)
 
-from label_studio.core.label_config import parse_config
-from label_studio.core.utils.params import get_bool_env
-
-
 @attr.s
 class ModelWrapper(object):
     model = attr.ib()
@@ -295,7 +307,6 @@ class LabelStudioMLBase(ABC):
         return {}
 
     def get_local_path(self, url, project_dir=None):
-        from label_studio_ml.utils import get_local_path
         return get_local_path(url, project_dir=project_dir, hostname=self.hostname, access_token=self.access_token)
 
 
@@ -332,7 +343,7 @@ class LabelStudioMLManager(object):
             os.makedirs(cls.model_dir, exist_ok=True)
 
         cls._redis = None
-        if get_bool_env('USE_REDIS', True):
+        if get_bool_env('USE_REDIS', False):
             cls._redis = cls._get_redis(redis_host, redis_port)
         if cls._redis:
             cls._redis_queue = Queue(name=redis_queue, connection=cls._redis)
@@ -667,3 +678,29 @@ class LabelStudioMLManager(object):
         job_id = cls._generate_version()
         cls.get_job_manager().run_job(cls.model_class, (event, data, job_id))
         return {'job_id': job_id}
+
+
+def get_all_classes_inherited_LabelStudioMLBase(script_file):
+    names = set()
+    abs_path = os.path.abspath(script_file)
+    module_name = os.path.splitext(os.path.basename(script_file))[0]
+    sys.path.append(os.path.dirname(abs_path))
+    try:
+        module = importlib.import_module(module_name)
+    except ModuleNotFoundError as e:
+        print(Fore.RED + 'Can\'t import module "' + module_name + f'", reason: {e}.\n'
+              'If you are looking for examples, you can find a dummy model.py here:\n' +
+              Fore.LIGHTYELLOW_EX + 'https://labelstud.io/tutorials/dummy_model.html')
+        module = None
+        exit(-1)
+
+    for name, obj in inspect.getmembers(module, inspect.isclass):
+        if name == LabelStudioMLBase.__name__:
+            continue
+        if issubclass(obj, LabelStudioMLBase):
+            names.add(name)
+        for base in obj.__bases__:
+            if LabelStudioMLBase.__name__ == base.__name__:
+                names.add(name)
+    sys.path.pop()
+    return list(names)
